pub struct PermissionManager { /* private fields */ }Expand description
Permission management service
Implementations
Sourceimpl PermissionManager
impl PermissionManager
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new permission manager.
Loads persisted permissions from ~/.config/gestura/permissions.json (or
the platform equivalent). The audit log is kept in-memory only.
Sourcepub fn from_config_path(config_path: PathBuf) -> Self
pub fn from_config_path(config_path: PathBuf) -> Self
Create a permission manager backed by an explicit config path.
This is useful for tests and isolated runtimes that must avoid reading or writing the default user-scoped permissions file.
Sourcepub fn audit_log(&self) -> Result<Vec<PermissionAuditEntry>>
pub fn audit_log(&self) -> Result<Vec<PermissionAuditEntry>>
Return a snapshot of the permission audit log.
Sourcepub fn clear_audit_log(&self) -> Result<usize>
pub fn clear_audit_log(&self) -> Result<usize>
Clear the permission audit log.
Returns the number of entries removed.
Sourcepub fn list(&self) -> Result<Vec<Permission>>
pub fn list(&self) -> Result<Vec<Permission>>
List all permissions
Sourcepub fn grant(
&self,
tool: &str,
action: &str,
scope: PermissionScope,
ttl_secs: Option<u64>,
) -> Result<Permission>
pub fn grant( &self, tool: &str, action: &str, scope: PermissionScope, ttl_secs: Option<u64>, ) -> Result<Permission>
Grant a permission